<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns:oval-def="http://oval.mitre.org/XMLSchema/oval-definitions-5"
    xmlns:win-def="http://oval.mitre.org/XMLSchema/oval-definitions-5#windows"
    xmlns:cdf="http://checklists.nist.gov/xccdf/1.1"
    xmlns:xsd="http://www.w3.org/2001/XMLSchema"   
    xmlns:oval-res="http://oval.mitre.org/XMLSchema/oval-results-5"
    xmlns:oval-sc="http://oval.mitre.org/XMLSchema/oval-system-characteristics-5"
    xmlns:oval-ind="http://oval.mitre.org/XMLSchema/oval-definitions-5#independent"
    xmlns:ind-sc="http://oval.mitre.org/XMLSchema/oval-system-characteristics-5#independent"
    xmlns:win-sc="http://oval.mitre.org/XMLSchema/oval-system-characteristics-5#windows"
    xmlns:xalan="http://xml.apache.org/xalan"
    >
    
    <!--
        
        For which definition is this XSLT appilcable ?
        
        This library is a modified version of winSystemConfigurationCheck01.xsl.
        Corresponding txt is winSystemConfigurationCheck01_SCAP_xsl.txt
        
        Modified the existing lib for def id's:
        oval:com.mcafee.oval.windows:def:6565
        oval:com.mcafee.oval.windows:def:6600
        
        Library was modified for Printable Values as per the input and also to display the input value in the findings message
        when system is set to Not Configured/Disabled.
     
    -->
    
    <xsl:variable name="Definitions"
        select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:definitions"/>
    <xsl:variable name="Tests"
        select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:tests"/>
    <xsl:variable name="TestedItems"
        select="/oval-res:oval_results/oval-res:results/oval-res:system/oval-res:tests"/>
    <xsl:variable name="CollectedObjects"
        select="/oval-res:oval_results/oval-res:results/oval-res:system/oval-sc:oval_system_characteristics/oval-sc:collected_objects"/>
    <xsl:variable name="SystemData"
        select="/oval-res:oval_results/oval-res:results/oval-res:system/oval-sc:oval_system_characteristics/oval-sc:system_data"/>
    <xsl:variable name="States"
        select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:states"/>
    <xsl:variable name="Objects"
        select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:objects"/>
    <xsl:variable name="Variables"
        select="/oval-res:oval_results/oval-def:oval_definitions/oval-def:variables"/>
    <xsl:variable name="OvalResult"
        select="/oval-res:oval_results/oval-res:results/oval-res:system/oval-res:definitions"/>
    
    
    
    <xsl:template name="toggleBoolean">
        <xsl:param name="value"/>
        <xsl:choose>
            <xsl:when test="$value = 'true'">
                <xsl:value-of select="false()"/>
            </xsl:when>
            <xsl:when test="$value = 'false'">
                <xsl:value-of select="true()"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="true()"/>
            </xsl:otherwise>
        </xsl:choose>
        
        
    </xsl:template>
    
    <xsl:template name="removeColon">
        <xsl:param name="string"/>
        <xsl:param name="count"/>
        <xsl:param name="length"/>
        
        <xsl:if test="$count  &lt;= $length">
            
            <xsl:variable name="char">
                <xsl:value-of select="substring($string,$count,1)"/>
            </xsl:variable>
            
            <xsl:choose>
                <xsl:when test="$char != ':' and $char != '.' ">
                    <xsl:value-of select="$char"/>
                    <xsl:call-template name="removeColon">
                        <xsl:with-param name="string" select="$string"/>
                        <xsl:with-param name="count" select="$count + 1"/>
                        <xsl:with-param name="length" select="$length"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>                  
                    <xsl:call-template name="removeColon">
                        <xsl:with-param name="string" select="$string"/>
                        <xsl:with-param name="count" select="$count + 1"/>
                        <xsl:with-param name="length" select="$length"/>
                    </xsl:call-template>
                </xsl:otherwise>
            </xsl:choose>          
        </xsl:if>
        
    </xsl:template>
    
    <xsl:template name="getSuffixForMessageId">
        <xsl:param name="id"/>      
        
        <xsl:variable name="suffix">
            <xsl:value-of select="substring-after($id,'oval:com.mcafee.')"/>
        </xsl:variable>
        
        <xsl:variable name="suffix1">
            <xsl:call-template name="removeColon">
                <xsl:with-param name="string" select="$suffix"/>
                <xsl:with-param name="length" select="string-length($suffix)"/>
                <xsl:with-param name="count" select="1 + 0"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:value-of select="$suffix1"/>
    </xsl:template>
    
    <xsl:template name="getMessageId">
        <xsl:param name="id"/>
        <xsl:param name="status"/>
        
        <xsl:variable name="suffiex">
            <xsl:call-template name="getSuffixForMessageId">
                <xsl:with-param name="id" select="$id"/>                
            </xsl:call-template>
        </xsl:variable>
        
        <xsl:if test="$suffiex != '' ">
            <xsl:choose>
                <xsl:when test="$status = 'does not exist' ">
                    <xsl:value-of select="concat('com.mcafee.pa.msg.winnoconfiguration',$suffiex)"/>
                </xsl:when>
                <xsl:otherwise>
                        <xsl:value-of select="concat('com.mcafee.pa.msg.winconfiguration',$suffiex)"/>
                </xsl:otherwise>                
             </xsl:choose>
        </xsl:if>
    </xsl:template>
    
    
   <!--  <xsl:template name="getPossibleValue">
        <xsl:param name="id"/>
        <xsl:choose>            
            <xsl:when test="$id = 'oval:com.mcafee.oval.windows:var:6600'">
                <xsl:text>1-Low Level,2-Client Compatible,3-High Level,99999-Not Configured/Disabled</xsl:text>
            </xsl:when>
            
            <xsl:when test="$id = 'oval:com.mcafee.oval.windows:var:6565'">
                <xsl:text>0-None,1-Authenticated,2-Authenticated without exceptions,99999-Not Configured/Disabled</xsl:text>
            </xsl:when>
            
            <xsl:when test="$id = 'oval:com.mcafee.oval:var:72015'">
                <xsl:text>255-All drives,181-CD-ROM and removable media drives,99999-Not Configured/Disabled</xsl:text>
            </xsl:when>
       </xsl:choose>
    </xsl:template> -->
    
    <xsl:template name="getExternalVariablePrintableValue">
        <xsl:param name="id"/>
        <xsl:param name="numaricValue"/>
        
        <xsl:variable name="value">
            <xsl:value-of select="normalize-space($numaricValue)"/>    
        </xsl:variable>
        
        <!-- <xsl:variable name="possibleValues">
            <xsl:call-template name="getPossibleValue">
                <xsl:with-param name="id" select="normalize-space($id)"/>
            </xsl:call-template>
        </xsl:variable> -->


        <!-- <xsl:variable name="printableValue">
            <xsl:if test="contains($possibleValues,$value)">
                <xsl:variable name="var1" select="substring-after($possibleValues, concat($value,'-') )"/>
                <xsl:choose>
                    <xsl:when test="contains($var1, ',' )">
                        <xsl:value-of select="substring-before($var1, ',' )"/>
                    </xsl:when>
                    <xsl:otherwise>
                         <xsl:value-of select="$var1"/>
                    </xsl:otherwise>
                </xsl:choose>               
          </xsl:if>
          </xsl:variable> -->
        
        <xsl:variable name="printableValue">
            <xsl:for-each
                select="$Variables/oval-def:external_variable[@id = $id]/descendant::oval-def:possible_value">
                <xsl:if test="text() = $numaricValue">
                    <xsl:value-of select="@hint"/>
                </xsl:if>
            </xsl:for-each>
        </xsl:variable>
        
        <xsl:variable name="printableValueRange">
            <xsl:for-each
                select="$Variables/oval-def:external_variable[@id = $id]/descendant::oval-def:possible_restriction">
                <xsl:value-of select=" substring-before(@hint,'. Range')"/>
            </xsl:for-each>
        </xsl:variable>
        
        <xsl:variable name="formattedNumaricValue">
            <xsl:choose> 
                <xsl:when test="$value = ''  ">
                    <xsl:text>Not Configured/Disabled</xsl:text>                    
                </xsl:when>
                <xsl:when test="$printableValue != '' ">
                    <xsl:value-of select="concat($printableValue, '(' , $value , ')' )"/>
                </xsl:when>
                <xsl:when test="$printableValueRange != '' ">
                    <xsl:value-of select="concat($printableValueRange, '(' , $value , ')' )"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$value"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable> 
        
       <xsl:value-of select="$formattedNumaricValue"/>
        
    </xsl:template>
         
    <xsl:template name="getFindings">
        <xsl:param name="definitionId"/>
        
        <xsl:variable name="result"
            select="/oval-res:oval_results/oval-res:results/oval-res:system/oval-res:definitions/oval-res:definition[@definition_id=$definitionId]/@result"/>
        
        <xsl:call-template name="winConfigurationCheck">
                <xsl:with-param name="definitionId" select="$definitionId"/>
                <xsl:with-param name="def_result" select="$result"/>
         </xsl:call-template>
        
        
    </xsl:template>
    
    <xsl:template name="winConfigurationCheck">
        <xsl:param name="definitionId"/>       
        <xsl:param name="def_result"/>
        
        <xsl:variable name="tests">        
            <xsl:for-each select="$OvalResult/oval-res:definition[ @definition_id = $definitionId ]/oval-res:criteria/descendant::oval-res:criterion">
                
                <xsl:variable name="test" select="@test_ref"/>
                
                 <xsl:if test="$Tests/win-def:registry_test[@id=$test]">
                    <xsl:variable name="object" select="$Tests/win-def:registry_test[@id=$test]/win-def:object/@object_ref"/>
                    <xsl:variable name="state"  select="$Tests/win-def:registry_test[@id=$test]/win-def:state/@state_ref"/>
                    
                    <xsl:variable name="key" select="$Objects/win-def:registry_object[@id=$object]/win-def:key"/>
                    <xsl:variable name="name" select="$Objects/win-def:registry_object[@id=$object]/win-def:name"/>
                    
                    <xsl:variable name="externalVar" select="$States/win-def:registry_state[@id=$state]/win-def:value/@var_ref"/>
                    <xsl:variable name="operation" select="$States/win-def:registry_state[@id=$state]/win-def:value/@operation"/>
                     
                     <!-- This is a variable test id which contains expected value when system setting is "Not Configured" - Reg key does not exist -->
                     <xsl:variable name="VarId" select="$Tests/oval-ind:variable_test/@id"/>
                     
                    
                    <xsl:element name="test">
                        <xsl:attribute name="id">
                            <xsl:value-of select="$test"/>
                        </xsl:attribute>
                                
                        <xsl:attribute name="key">
                            <xsl:value-of select="$key"/>
                        </xsl:attribute>
                        
                        <xsl:attribute name="state">
                            <xsl:value-of select="$state"/>
                        </xsl:attribute>
                        
                        <xsl:attribute name="name">
                            <xsl:value-of select="$name"/>
                        </xsl:attribute>
                        
                        <xsl:attribute name="externalVar">
                            <xsl:value-of select="$externalVar"/>
                        </xsl:attribute>
                        
                        <!-- This is a variable test id which contains expected value when system setting is "Not Configured" - Reg key does not exist -->
                        <xsl:attribute name="VarID">
                            <xsl:value-of select="$VarId"/>
                        </xsl:attribute>
                        
                        <xsl:attribute name="operation">
                            <xsl:value-of select="$operation"/>
                        </xsl:attribute>
                        
                        <xsl:if test="$States/win-def:registry_state[@id=$state]/win-def:value or $state = '' ">
                            <xsl:attribute name="type">
                                <xsl:text>primarytest</xsl:text>
                            </xsl:attribute>
                        </xsl:if>
                        
                        <xsl:if test="$States/win-def:registry_state[@id=$state]/win-def:type and not($States/win-def:registry_state[@id=$state]/win-def:value)">
                            <xsl:attribute name="type">
                                <xsl:text>typecheckingtest</xsl:text>
                            </xsl:attribute>
                            <xsl:attribute name="typeName">
                                <xsl:value-of select="$States/win-def:registry_state[@id=$state]/win-def:type"/>
                            </xsl:attribute>
                        </xsl:if>                        
                    </xsl:element>
                </xsl:if>
                
                <xsl:if test="$Tests/oval-ind:family_test[@id=$test]">
                    <xsl:element name="test">
                        <xsl:attribute name="id">
                            <xsl:value-of select="$test"/>
                        </xsl:attribute>
                        <xsl:attribute name="type">
                            <xsl:text>family</xsl:text>
                        </xsl:attribute>                        
                    </xsl:element>
                </xsl:if>
                
                
            </xsl:for-each>            
            
        </xsl:variable>
        
     
     
        <xsl:variable name="exDefinitionId">
            <xsl:for-each
                select="/oval-res:oval_results/oval-res:results/oval-res:system/oval-res:definitions/oval-res:definition[ @definition_id = $definitionId ]/oval-res:criteria/descendant::oval-res:extend_definition[@result = 'false'] ">
                <xsl:if test="./parent::node()/@result = 'false' ">
                    <xsl:element name="extend_definition">
                        <xsl:attribute name="id">
                            <xsl:value-of select="@definition_ref"/>
                        </xsl:attribute>
                        <xsl:attribute name="result">
                            <xsl:value-of select="@result"/>
                        </xsl:attribute>
                    </xsl:element>
                </xsl:if>
            </xsl:for-each>
        </xsl:variable>
        
        <xsl:variable name="rs_exDefinition">
            <xsl:value-of
                select="xalan:nodeset($exDefinitionId)/descendant::extend_definition/@result"/>
        </xsl:variable>
        
        <xsl:variable name="pre_test_result">
            <xsl:choose>
                <xsl:when test="$rs_exDefinition != '' ">
                    <xsl:value-of select="$rs_exDefinition"/>
                </xsl:when>
                <xsl:when
                    test="xalan:nodeset($tests)/descendant::test[ @type ='family' ]/@id != '' ">
                    <xsl:variable name="test"
                        select="xalan:nodeset($tests)/descendant::test[ @type ='family' ]/@id"/>
                    <xsl:value-of select="$TestedItems/oval-res:test[@test_id=$test ]/@result"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>true</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        
               
            
            <xsl:if test=" $pre_test_result = 'true'  and $def_result = 'false' ">
                <findings id="{$definitionId}" xmlns="http://results.pa.mcafee.com/findings/5.2">        
                <xsl:for-each select="xalan:nodeset($tests)/descendant::test[ @type ='typecheckingtest' ]">
                    <xsl:variable name="test" select="@id"/>
                    <xsl:variable name="key" select="@key"/>
                    <xsl:variable name="name" select="@name"/>                    
                    <xsl:variable name="typeName" select="@typeName"/>
                    
                    <xsl:for-each  select="$TestedItems/oval-res:test[@test_id=$test ]/oval-res:tested_item[ @result = 'false' ] ">
                        
                        <xsl:variable name="itemRef" select="@item_id"/>
                        <xsl:variable name="result" select="@result"/>
                        
                        <xsl:variable name="actualParameterType" select="$SystemData/win-sc:registry_item[@id=$itemRef]/win-sc:type"/>
                        
                        <xsl:if test="$actualParameterType != '' ">
                            <finding messageId="com.mcafee.pa.msg.winregistryvaluetypeisinvalid" isViolation="true">                                
                                <instanceValue key="registry">
                                    <xsl:value-of select="$key"/><xsl:text>\</xsl:text><xsl:value-of select="$name"/>                                                    
                                </instanceValue>                                
                                <instanceValue key="expectedType">
                                    <xsl:value-of select="$typeName"/>                                                    
                                </instanceValue>
                                <actualValue key="actualType">
                                    <xsl:value-of select="$actualParameterType"/>                                                    
                                </actualValue>
                            </finding>
                        </xsl:if>
                    </xsl:for-each>
                </xsl:for-each>
                
                <xsl:for-each select="xalan:nodeset($tests)/descendant::test[ @type ='primarytest']">
                    <xsl:variable name="test" select="@id"/>
                    
                    <!-- This is a variable test id which contains expected value when system setting is "Not Configured" - Reg key does not exist -->
                    <xsl:variable name="varId" select="@VarID"/>
                    
                    <xsl:variable name="state" select="@state"/>
                    <xsl:variable name="key" select="@key"/>
                    <xsl:variable name="name" select="@name"/>
                    
                    <xsl:variable name="externalVarId" select="@externalVar"/>
                    <xsl:variable name="operation" select="@operation"/>
                    
                    <xsl:if test="$externalVarId != '' ">
                        
                        <!-- Get expected value from the tested_variable of registry test id when when system setting is other than "Not Configured" - Reg key exist -->
                        <xsl:variable name="externalVarValue"
                            select="$TestedItems/oval-res:test[@test_id=$test ]/oval-res:tested_variable[@variable_id = $externalVarId]"/>
                        
                        <!-- Get expected value from the tested_varibale of variable test id when when system setting is "Not Configured" - Reg key does not exist -->
                        <xsl:variable name="externalVarValue1"
                                select="$TestedItems/oval-res:test[@test_id=$varId ]/oval-res:tested_variable[@variable_id = $externalVarId]"/>
                       
                        
                        <!-- Pass the value for numaricValue parameter based on not null value of $externalVarValue and $externalVarValue1 to get the printable value from the template -->
                        
                        <xsl:variable name="inputRegistryParameterValue">
                            <xsl:choose>
                                <xsl:when test="$externalVarValue != ''">
                                        <xsl:call-template name="getExternalVariablePrintableValue">
                                            <xsl:with-param name="id" select="$externalVarId"  />
                                            <xsl:with-param name="numaricValue" select="$externalVarValue"/>
                                        </xsl:call-template>
                                </xsl:when>
                                <xsl:otherwise>
                                        <xsl:call-template name="getExternalVariablePrintableValue">
                                            <xsl:with-param name="id" select="$externalVarId"  />
                                            <xsl:with-param name="numaricValue" select="$externalVarValue1"/>
                                        </xsl:call-template>
                                </xsl:otherwise>
                            </xsl:choose>
                      </xsl:variable> 
                       
                        <inputValue key="expectedValue">
                            <xsl:value-of select="$inputRegistryParameterValue"/>                                                    
                        </inputValue>
                       
                            <!-- <xsl:variable name="inputRegistryParameterValue">
                                <xsl:call-template name="getExternalVariablePrintableValue">
                                    <xsl:with-param name="id" select="$externalVarId"  />
                                    <xsl:with-param name="numaricValue" select="$externalVarValue"/>
                                </xsl:call-template>
                            </xsl:variable> -->
                      
                        
                        <xsl:for-each  select="$TestedItems/oval-res:test[@test_id=$test ]/oval-res:tested_item[ @result = 'false'  or @result = 'error'  or  @result='not evaluated' ] ">
                            
                            <xsl:variable name="itemRef" select="@item_id"/>
                            <xsl:variable name="result" select="@result"/>
                            
                            <xsl:variable name="actualParameterValue" select="$SystemData/win-sc:registry_item[@id=$itemRef]/win-sc:value"/>
                            <xsl:variable name="actualParameterStatus"
			      select="$SystemData/win-sc:registry_item[@id=$itemRef]/win-sc:name/@status"/>
                            
                            <xsl:variable name="actualParameterPrintableValue">
                                <xsl:call-template name="getExternalVariablePrintableValue">
                                    <xsl:with-param name="id" select="$externalVarId"  />
                                    <xsl:with-param name="numaricValue" select="$actualParameterValue"/>
                                </xsl:call-template>
                            </xsl:variable> 
                            
                            <xsl:variable name="message_id">
				 <xsl:call-template name="getMessageId">
				     <xsl:with-param name="id" select="normalize-space($definitionId)"/>
				     <xsl:with-param  name="status" select="normalize-space($actualParameterStatus)"/>
				 </xsl:call-template>
                            </xsl:variable>
                            
                            
                            <finding messageId="{$message_id}" isViolation="true">                                                            

                                <actualValue key="actualValue">
                                    <xsl:value-of select="$actualParameterPrintableValue"/>                                                    
                                </actualValue>
                            </finding>
                        </xsl:for-each>
                         
                    </xsl:if>
                    
                    <xsl:if test=" $state = '' ">
                        <xsl:for-each
                            select="$TestedItems/oval-res:test[@test_id=$test ]/oval-res:tested_item[ @result = 'false'  or @result = 'error'  or  @result='not evaluated' ] ">
                            
                            <xsl:variable name="itemRef" select="@item_id"/>
                            <xsl:variable name="result" select="@result"/>
                            
                            <xsl:variable name="actualParameterValue"
                                select="$SystemData/win-sc:registry_item[@id=$itemRef]/win-sc:value"/>
                            <xsl:variable name="actualParameterStatus"
                                select="$SystemData/win-sc:registry_item[@id=$itemRef]/win-sc:name/@status"/>
                            
                            <xsl:variable name="message_id">
                                <xsl:choose>
                                    <xsl:when
                                        test="$actualParameterStatus = 'does not exist' ">
                                        <xsl:text>com.mcafee.pa.msg.winregistryisnotexist</xsl:text>
                                    </xsl:when>
                                    <xsl:when test="$result = 'error' or  $result='not evaluated' ">
                                        <xsl:text>com.mcafee.pa.msg.winregistryreaderror</xsl:text>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>com.mcafee.pa.msg.winregistryisexist</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:variable>
                            
                            <finding messageId="{$message_id}" isViolation="true">                                        
                                <instanceValue key="registry">
                                    <xsl:value-of select="$key"/><xsl:text>\</xsl:text><xsl:value-of select="$name"/>
                                </instanceValue>                                      
                            </finding>
                        </xsl:for-each>
                    </xsl:if>
                    
                </xsl:for-each>
              </findings>
            </xsl:if>
        
            <xsl:if test="$def_result = 'true' ">              
                <findings id="{$definitionId}" xmlns="http://results.pa.mcafee.com/findings/5.2">
                <xsl:for-each select="xalan:nodeset($tests)/descendant::test[ @type ='primarytest']">
                    <xsl:variable name="test" select="@id"/>
                    <xsl:variable name="state" select="@state"/>
                    <xsl:variable name="key" select="@key"/>
                    <xsl:variable name="name" select="@name"/>
                    
                    <xsl:variable name="externalVarId" select="@externalVar"/>
                    <xsl:variable name="operation" select="@operation"/>
                    
                    <!-- This is a variable test id which contains expected value when system setting is "Not Configured" - Reg key does not exist -->
                    <xsl:variable name="varId" select="@VarID"/>
                    
                    <xsl:if test="$externalVarId != '' ">
                        
                        <xsl:variable name="externalVarValue" 
                        select="$TestedItems/oval-res:test[@test_id=$test ]/oval-res:tested_variable[@variable_id = $externalVarId]"/>
                        
                        
                        <!-- Get expected value from the tested_varibale of variable test id when when system setting is "Not Configured" - Reg key does not exist -->
                        <xsl:variable name="externalVarValue1"
                            select="$TestedItems/oval-res:test[@test_id=$varId ]/oval-res:tested_variable[@variable_id = $externalVarId]"/>
                        
                        <!-- <xsl:variable name="inputRegistryParameterValue">
                            <xsl:call-template name="getExternalVariablePrintableValue">
                                <xsl:with-param name="id" select="$externalVarId"  />
                                <xsl:with-param name="numaricValue" select="$externalVarValue"/>
                            </xsl:call-template>
                            </xsl:variable> -->
                        
                        
                        <xsl:variable name="inputRegistryParameterValue">
                            <xsl:choose>
                                <xsl:when test="$externalVarValue != ''">
                                    <xsl:call-template name="getExternalVariablePrintableValue">
                                        <xsl:with-param name="id" select="$externalVarId"  />
                                        <xsl:with-param name="numaricValue" select="$externalVarValue"/>
                                    </xsl:call-template>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:call-template name="getExternalVariablePrintableValue">
                                        <xsl:with-param name="id" select="$externalVarId"  />
                                        <xsl:with-param name="numaricValue" select="$externalVarValue1"/>
                                    </xsl:call-template>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        
                        <inputValue key="expectedValue">
                            <xsl:value-of select="$inputRegistryParameterValue"/>                                                    
                        </inputValue>
                        <!-- <xsl:for-each  select="$TestedItems/oval-res:test[@test_id=$test ]/oval-res:tested_item[ @result = 'true' ]"> -->
                   <xsl:choose>
                       <xsl:when test="$TestedItems/oval-res:test[@test_id=$test ]/oval-res:tested_item[ @result = 'true' ]">
                           <xsl:for-each  select="$TestedItems/oval-res:test[@test_id=$test ]/oval-res:tested_item[ @result = 'true' ]">
                               
                               <xsl:variable name="itemRef" select="@item_id"/>
                               <xsl:variable name="result" select="@result"/>
                               
                               <xsl:variable name="actualParameterValue" select="$SystemData/win-sc:registry_item[@id=$itemRef]/win-sc:value"/>
                               <xsl:variable name="actualParameterStatus"
                                   select="$SystemData/win-sc:registry_item[@id=$itemRef]/win-sc:name/@status"/>
                               
                               <xsl:variable name="actualParameterPrintableValue">
                                   <xsl:call-template name="getExternalVariablePrintableValue">
                                       <xsl:with-param name="id" select="$externalVarId"  />
                                       <xsl:with-param name="numaricValue" select="$actualParameterValue"/>
                                   </xsl:call-template>
                               </xsl:variable> 
                               
                               <xsl:variable name="message_id">
                                   <xsl:call-template name="getMessageId">
                                       <xsl:with-param name="id" select="normalize-space($definitionId)"/>
                                       <xsl:with-param  name="status" select="normalize-space($actualParameterStatus)"/>
                                   </xsl:call-template>
                               </xsl:variable>
                               
                               
                               <finding messageId="{$message_id}" isViolation="false">                                                            
                                   
                                   <actualValue key="actualValue">
                                       <xsl:value-of select="$actualParameterPrintableValue"/>                                                    
                                   </actualValue>
                               </finding>
                           </xsl:for-each>
                       </xsl:when>
                       <xsl:otherwise>
                           <xsl:for-each  select="$TestedItems/oval-res:test[@test_id=$varId]/oval-res:tested_item[ @result = 'true' ] ">    
                               <xsl:variable name="itemRef" select="@item_id"/>
                               <xsl:variable name="result" select="@result"/>
                               
                               <xsl:variable name="actualParameterValue" select="$SystemData/win-sc:registry_item[@id=$itemRef]/win-sc:value"/>
                               <xsl:variable name="actualParameterStatus"
                                   select="$SystemData/win-sc:registry_item[@id=$itemRef]/win-sc:name/@status"/>
                               
                               <xsl:variable name="actualParameterPrintableValue">
                                   <xsl:call-template name="getExternalVariablePrintableValue">
                                       <xsl:with-param name="id" select="$externalVarId"  />
                                       <xsl:with-param name="numaricValue" select="$actualParameterValue"/>
                                   </xsl:call-template>
                               </xsl:variable> 
                               
                               <xsl:variable name="message_id">
                                   <xsl:call-template name="getMessageId">
                                       <xsl:with-param name="id" select="normalize-space($definitionId)"/>
                                       <xsl:with-param  name="status" select="normalize-space($actualParameterStatus)"/>
                                   </xsl:call-template>
                               </xsl:variable>
                               
                               
                               <finding messageId="{$message_id}" isViolation="false">                                                            
                                   
                                   <actualValue key="actualValue">
                                       <xsl:value-of select="$actualParameterPrintableValue"/>                                                    
                                   </actualValue>
                               </finding>
                           </xsl:for-each>    
                       </xsl:otherwise>
                   </xsl:choose>
                    </xsl:if>
                </xsl:for-each>
                </findings>
            </xsl:if>
        
          <xsl:if test="$pre_test_result = 'false'  and $def_result = 'false' ">
            <xsl:variable name="getIE7InstallationResult">
                <xsl:value-of  select="xalan:nodeset($exDefinitionId)/descendant::extend_definition[@id = 'oval:com.mcafee.oval.ie7:def:627']/@result"/>
            </xsl:variable>
            <xsl:if  test="$getIE7InstallationResult = 'false' ">
                <findings id="{$definitionId}" xmlns="http://results.pa.mcafee.com/findings/5.2">        
                    <finding messageId="com.mcafee.pa.msg.ie7isnotinstalled" isViolation="true"/>
                </findings>
            </xsl:if>
        </xsl:if>
    
    </xsl:template>
    
</xsl:stylesheet>